@@ -4,11 +4,14 @@ from json.decoder import JSONDecodeError
 
 def json_post(url, data):
     try:
-        return json.loads(
-            requests.post(
-                url,
-                data=json.dumps(data, ensure_ascii=False).encode(encoding='utf-8'), 
-                headers={"Content-Type": "application/json"}).text)
+        text = requests.post(
+            url,
+            data=json.dumps(data, ensure_ascii=False).encode(encoding='utf-8'), 
+            headers={"Content-Type": "application/json"}).text
+        try:
+            return json.loads(text)
+        except JSONDecodeError:
+            return text
     except Exception as e:
         return e
 
